@@ -30,6 +30,9 @@
 runUnitTests <- function() {
 	
 	pkg <- "XLConnect"
+	
+	# Option to determine if full test suite should be run
+	options("FULL.TEST.SUITE" = Sys.getenv("FULL_TEST_SUITE") == "1")
 
 	# RUnit is required for unit testing
 	if(require("RUnit", quietly = TRUE)) {
