@@ -29,7 +29,7 @@
 with.workbook <- function(data, expr, ...) {
 	env <- new.env(parent = parent.frame())
 	for(name in getDefinedNames(data, validOnly = TRUE)) {
-		tryCatch(assign(make.names(name), readNamedRegion(data, name = name, ...), env = env),
+		tryCatch(assign(make.names(name), readNamedRegion(data, name = name, ...), envir = env),
 			error = function(e) {
 				warning(e)
 			}
