@@ -186,4 +186,42 @@ test.workbook.readWorksheet <- function() {
 			forceConversion = TRUE,
 			dateTimeFormat = "%d.%m.%Y %H:%M:%S")
 	checkEquals(res, targetForce)
+	
+	target = list(
+			AAA = data.frame(
+					A = 1:3,
+					B = letters[1:3],
+					C = c(TRUE, TRUE, FALSE),
+					stringsAsFactors = FALSE
+			),
+			BBB = data.frame(
+					D = 4:6,
+					E = letters[4:6],
+					F = c(FALSE, TRUE, TRUE),
+					stringsAsFactors = FALSE
+			)
+	)
+	
+	# Check that reading multiple worksheets (by name) returns a named list (*.xls)
+	res <- readWorksheet(wb.xls, sheet = c("AAA", "BBB"), header = TRUE)
+	checkEquals(res, target)
+	
+	# Check that reading multiple worksheets (by name) returns a named list (*.xlsx)
+	res <- readWorksheet(wb.xlsx, sheet = c("AAA", "BBB"), header = TRUE)
+	checkEquals(res, target)
+	
+	target = data.frame(
+		"With whitespace" = 1:4,
+		"And some other funky characters: _=?^~!$@#%" = letters[1:4],
+		check.names = FALSE,
+		stringsAsFactors = FALSE
+	)
+	
+	# Check that reading worksheets with check.names = FALSE works (*.xls)
+	res <- readWorksheet(wb.xls, sheet = "VariableNames", header = TRUE, check.names = FALSE)
+	checkEquals(res, target)
+	
+	# Check that reading worksheets with check.names = FALSE works (*.xlsx)
+	res <- readWorksheet(wb.xlsx, sheet = "VariableNames", header = TRUE, check.names = FALSE)
+	checkEquals(res, target)
 }
