@@ -64,8 +64,44 @@ public class App
 {
     public static void main( String[] args ) throws Exception
     {
-        Workbook wbx = Workbook.getWorkbook("D:/mirai/workspace/next_release/XLConnect-R/inst/demoFiles/mtcars.xlsx", false);
-        wbx.clearSheet(2);
+        Workbook wbx = Workbook.getWorkbook("test.xlsx", true);
+        wbx.createSheet("test");
+        wbx.createName("test", "test!$A$1", false);
+        wbx.writeNamedRegion(new DataFrame(), "test", false);
+        wbx.save();
+       
+        if(1 == 1) return;
+        
+        /* Performance measurements */
+        int nrows = 10000, ncols = 100;
+
+        File f = new File("C:/Users/mstuder/Documents/perf.xls");
+        if(f.exists()) f.delete();
+
+        long start = System.currentTimeMillis();
+
+        DataFrame dfx = new DataFrame();
+        for(int i = 0; i < ncols; i++) {
+            ArrayList<Double> v = new ArrayList<Double>(nrows);
+            for(int j = 0; j < nrows; j++)
+                v.add(Math.random());
+
+            dfx.addColumn(Integer.toString(i), DataType.Numeric, v);
+        }
+
+        long end = System.currentTimeMillis();
+        System.out.println("Data creation: " + (end - start));
+
+        Workbook wb = Workbook.getWorkbook(f, true);
+        wb.createSheet("MyData");
+        start = System.currentTimeMillis();
+        wb.writeWorksheet(dfx, "MyData", true);
+        end = System.currentTimeMillis();
+        System.out.println("Write worksheet: " + (end - start));
+        start = System.currentTimeMillis();
+        wb.save();
+        end = System.currentTimeMillis();
+        System.out.println("Save: " + (end - start));
 
         
         /*
